@@ -1,4 +1,4 @@
-import importlib
+from importlib.machinery import SourceFileLoader
 import os
 import sys
 import argparse
@@ -16,12 +16,12 @@ def parse_options(args_):
     parser.add_argument('--no-error', action='store_true', default=False, help='if turned on the program won\'t raise errors, just print the fails. This should be turned off when using github actions')
     parser.add_argument('--one-error', action='store_true', default=False, help='if turned on the program will only raise one error after all tests were tested')
 
-    return parser.parse_args(os.cwd() + '/' + args_)
+    return parser.parse_args(args_)
 
 def import_files(file_):
     file_ = file_.replace('//', '.').replace('/', '.').replace('\\', '.').replace('.py', '')
 
-    x = importlib.import_module(file_)
+    x = SourceFileLoader(file_, os.getcwd()).load_module()
 
 def test_files(opts, path):
     smoke_test_done = False
